@@ -434,7 +434,7 @@ class WorkerPool(object):
             print(f'Requested run_on_host "{run_on_host}" is not in the hosts list. Releasing constraint ...')
 
         if self.env_file:
-            command = "sh -c '. %s; %s'" % (self.env_file, command)
+            command = "bash -c '. %s; %s'" % (self.env_file, command)
         if name is None:
             name = f'T{len(self.tasks)}'
 
